@@ -125,6 +125,10 @@ pub enum Action {
     ConfirmAction,
     /// Cancel action in dialog
     CancelAction,
+    /// Discard changes and quit (for unsaved changes dialogs)
+    DiscardAndQuit,
+    /// Discard changes and continue navigation (for unsaved changes dialogs)
+    DiscardAndContinue,
 
     // === Application ===
     /// Quit the application
@@ -181,6 +185,8 @@ pub enum Action {
     CommandPaletteNext,
     /// Navigate to previous command
     CommandPalettePrev,
+    /// Autocomplete selected command
+    CommandPaletteAutocomplete,
 
     // === Doc Search Navigation ===
     /// Next search match
@@ -259,6 +265,8 @@ impl Action {
             // Dialog
             Action::ConfirmAction => "Confirm",
             Action::CancelAction => "Cancel",
+            Action::DiscardAndQuit => "Discard changes and quit",
+            Action::DiscardAndContinue => "Discard changes and continue",
 
             // Application
             Action::Quit => "Quit",
@@ -304,6 +312,7 @@ impl Action {
             Action::OpenCommandPalette => "Open command palette",
             Action::CommandPaletteNext => "Next command",
             Action::CommandPalettePrev => "Previous command",
+            Action::CommandPaletteAutocomplete => "Autocomplete command",
 
             // Doc search
             Action::NextMatch => "Next search match",
@@ -362,7 +371,10 @@ impl Action {
 
             Action::GoBack | Action::GoForward | Action::OpenInEditor | Action::UndoEdit => "Files",
 
-            Action::ConfirmAction | Action::CancelAction => "Dialog",
+            Action::ConfirmAction
+            | Action::CancelAction
+            | Action::DiscardAndQuit
+            | Action::DiscardAndContinue => "Dialog",
 
             Action::Quit => "Application",
 
@@ -396,7 +408,8 @@ impl Action {
 
             Action::OpenCommandPalette
             | Action::CommandPaletteNext
-            | Action::CommandPalettePrev => "Command Palette",
+            | Action::CommandPalettePrev
+            | Action::CommandPaletteAutocomplete => "Command Palette",
         }
     }
 }
