@@ -368,9 +368,12 @@ fn add_command_palette_mode(kb: &mut Keybindings) {
 
     // Navigation
     bind(kb, CommandPalette, "Down", CommandPaletteNext);
-    bind(kb, CommandPalette, "Tab", CommandPaletteNext);
+    bind(kb, CommandPalette, "j", CommandPaletteNext);
     bind(kb, CommandPalette, "Up", CommandPalettePrev);
-    bind(kb, CommandPalette, "Shift+Tab", CommandPalettePrev);
+    bind(kb, CommandPalette, "k", CommandPalettePrev);
+
+    // Autocomplete selected command
+    bind(kb, CommandPalette, "Tab", CommandPaletteAutocomplete);
 
     // Delete character
     bind(kb, CommandPalette, "Backspace", SearchBackspace);
@@ -389,6 +392,12 @@ fn add_confirm_dialog_mode(kb: &mut Keybindings) {
     bind(kb, ConfirmDialog, "n", CancelAction);
     bind(kb, ConfirmDialog, "N", CancelAction);
     bind(kb, ConfirmDialog, "Escape", CancelAction);
+
+    // Discard and quit (for unsaved changes dialogs)
+    bind(kb, ConfirmDialog, "q", DiscardAndQuit);
+
+    // Discard and continue (for navigation with unsaved changes)
+    bind(kb, ConfirmDialog, "d", DiscardAndContinue);
 }
 
 fn add_cell_edit_mode(kb: &mut Keybindings) {
