@@ -217,12 +217,12 @@ impl InteractiveState {
                                         ),
                                     });
 
-                                    self.element_states
-                                        .entry(nested_id)
-                                        .or_insert(ElementState::Table {
+                                    self.element_states.entry(nested_id).or_insert(
+                                        ElementState::Table {
                                             selected_row: 0,
                                             selected_col: 0,
-                                        });
+                                        },
+                                    );
 
                                     current_line += table_lines;
                                 }
@@ -280,37 +280,35 @@ impl InteractiveState {
                                                 ),
                                             };
 
-                                            let target =
-                                                if let Some(wikilink_target) =
-                                                    url.strip_prefix("wikilink:")
-                                                {
-                                                    LinkTarget::WikiLink {
-                                                        target: wikilink_target.to_string(),
-                                                        alias: if text != wikilink_target {
-                                                            Some(text.clone())
-                                                        } else {
-                                                            None
-                                                        },
-                                                    }
-                                                } else if let Some(anchor) = url.strip_prefix('#') {
-                                                    LinkTarget::Anchor(anchor.to_string())
-                                                } else if url.starts_with("http://")
-                                                    || url.starts_with("https://")
-                                                {
-                                                    LinkTarget::External(url.clone())
-                                                } else if let Some((path, anchor)) =
-                                                    url.split_once('#')
-                                                {
-                                                    LinkTarget::RelativeFile {
-                                                        path: path.into(),
-                                                        anchor: Some(anchor.to_string()),
-                                                    }
-                                                } else {
-                                                    LinkTarget::RelativeFile {
-                                                        path: url.into(),
-                                                        anchor: None,
-                                                    }
-                                                };
+                                            let target = if let Some(wikilink_target) =
+                                                url.strip_prefix("wikilink:")
+                                            {
+                                                LinkTarget::WikiLink {
+                                                    target: wikilink_target.to_string(),
+                                                    alias: if text != wikilink_target {
+                                                        Some(text.clone())
+                                                    } else {
+                                                        None
+                                                    },
+                                                }
+                                            } else if let Some(anchor) = url.strip_prefix('#') {
+                                                LinkTarget::Anchor(anchor.to_string())
+                                            } else if url.starts_with("http://")
+                                                || url.starts_with("https://")
+                                            {
+                                                LinkTarget::External(url.clone())
+                                            } else if let Some((path, anchor)) = url.split_once('#')
+                                            {
+                                                LinkTarget::RelativeFile {
+                                                    path: path.into(),
+                                                    anchor: Some(anchor.to_string()),
+                                                }
+                                            } else {
+                                                LinkTarget::RelativeFile {
+                                                    path: url.into(),
+                                                    anchor: None,
+                                                }
+                                            };
 
                                             self.elements.push(InteractiveElement {
                                                 id: nested_id,
@@ -408,9 +406,16 @@ impl InteractiveState {
                             });
                         }
 
-                        // Also extract links from list items (e.g., TOC links)
+                        // Extract links from list items (e.g., TOC links)
+                        // The parser provides line_offset for links inside list items
                         for (inline_idx, inline_elem) in item.inline.iter().enumerate() {
-                            if let InlineElement::Link { text, url, .. } = inline_elem {
+                            if let InlineElement::Link {
+                                text,
+                                url,
+                                line_offset,
+                                ..
+                            } = inline_elem
+                            {
                                 // Use a composite sub_idx to differentiate from checkboxes
                                 let id = ElementId {
                                     block_idx,
@@ -419,6 +424,10 @@ impl InteractiveState {
                                     ),
                                 };
 
+                                // Use parser-provided line_offset (0 for first line, 1 for second, etc.)
+                                let offset = line_offset.unwrap_or(0);
+                                let link_line = item_start_line + offset;
+
                                 // Parse link target
                                 let target = if let Some(wikilink_target) =
                                     url.strip_prefix("wikilink:")
@@ -453,15 +462,16 @@ impl InteractiveState {
                                     id,
                                     element_type: ElementType::Link {
                                         link: Link::new(text.clone(), target, 0),
-                                        line_idx: item_start_line,
+                                        line_idx: link_line,
                                     },
-                                    line_range: (item_start_line, item_start_line + 1),
+                                    line_range: (link_line, link_line + 1),
                                 });
                             }
                         }
 
-                        // Account for main item line
-                        current_line += 1;
+                        // Account for all lines in this item (main + nested)
+                        let item_line_count = item.content.lines().count().max(1);
+                        current_line += item_line_count;
 
                         // Process nested blocks within list items (code blocks, tables, etc.)
                         for (nested_idx, nested_block) in item.blocks.iter().enumerate() {
@@ -820,7 +830,9 @@ impl InteractiveState {
                     };
                     format!("Link: {}", text)
                 }
-                ElementType::Checkbox { content, checked, .. } => {
+                ElementType::Checkbox {
+                    content, checked, ..
+                } => {
                     let mark = if *checked { "☑" } else { "☐" };
                     let text = if content.len() > 15 {
                         format!("{}...", &content[..12])
@@ -1188,4 +1200,34 @@ fn main() {}
             state.elements.len()
         );
     }
+
+    #[test]
+    fn test_nested_list_item_links() {
+        // Test that links from nested list items are found in interactive mode
+        let markdown = r#"# Table of Contents
+
+- [Features](#features)
+  - [Interactive TUI](#interactive-tui)
+  - [CLI Mode](#cli-mode)
+- [Installation](#installation)
+"#;
+
+        let blocks = parse_content(markdown, 0);
+        let mut state = InteractiveState::new();
+        state.index_elements(&blocks);
+
+        // Count link elements
+        let link_count = state
+            .elements
+            .iter()
+            .filter(|e| matches!(e.element_type, ElementType::Link { .. }))
+            .count();
+
+        // Should find all 4 links: Features, Interactive TUI, CLI Mode, Installation
+        assert_eq!(
+            link_count, 4,
+            "Should find 4 links (including nested), found {}",
+            link_count
+        );
+    }
 }
