@@ -9,8 +9,8 @@ use crate::tui::app::{App, AppMode, Focus};
 use crate::tui::theme::Theme;
 use popups::{
     render_cell_edit_overlay, render_command_palette, render_file_create_confirm,
-    render_help_popup, render_link_picker, render_save_before_quit_confirm,
-    render_save_width_confirm, render_theme_picker,
+    render_help_popup, render_link_picker, render_save_before_nav_confirm,
+    render_save_before_quit_confirm, render_save_width_confirm, render_theme_picker,
 };
 use ratatui::Frame;
 use ratatui::layout::{Constraint, Layout, Rect};
@@ -52,7 +52,19 @@ pub fn render(frame: &mut Frame, app: &mut App) {
 
     // Create horizontal layout for outline and content (conditional based on outline visibility)
     let content_area = main_layout.require(Section::Content);
-    let content_chunks = if app.show_outline {
+
+    // Update viewport height for scroll calculations (subtract 2 for block borders)
+    app.set_viewport_height(content_area.height.saturating_sub(2));
+
+    // Minimum widths: outline needs at least 20 cols to be usable, content needs at least 40
+    const MIN_OUTLINE_WIDTH: u16 = 20;
+    const MIN_CONTENT_WIDTH: u16 = 40;
+    const MIN_TOTAL_WIDTH: u16 = MIN_OUTLINE_WIDTH + MIN_CONTENT_WIDTH;
+
+    // Decide whether to show outline based on terminal width
+    let effective_show_outline = app.show_outline && content_area.width >= MIN_TOTAL_WIDTH;
+
+    let content_chunks = if effective_show_outline {
         let content_width = 100 - app.outline_width;
         Layout::horizontal([
             Constraint::Percentage(app.outline_width),
@@ -64,8 +76,8 @@ pub fn render(frame: &mut Frame, app: &mut App) {
         Layout::horizontal([Constraint::Percentage(100)]).split(content_area)
     };
 
-    // Render outline (left pane) only if visible
-    if app.show_outline {
+    // Render outline (left pane) only if effectively visible (user toggle AND enough width)
+    if effective_show_outline {
         render_outline(frame, app, content_chunks[0]);
         // Render content (right pane)
         render_content(frame, app, content_chunks[1]);
@@ -117,6 +129,11 @@ pub fn render(frame: &mut Frame, app: &mut App) {
         render_save_before_quit_confirm(frame, app.pending_edits.len(), &app.theme);
     }
 
+    // Render save before navigate confirmation dialog
+    if matches!(app.mode, AppMode::ConfirmSaveBeforeNav) {
+        render_save_before_nav_confirm(frame, app.pending_edits.len(), &app.theme);
+    }
+
     // Render command palette
     if matches!(app.mode, AppMode::CommandPalette) {
         render_command_palette(frame, app, &app.theme);
@@ -428,7 +445,11 @@ fn render_status_bar(frame: &mut Frame, app: &App, area: Rect) {
     let status_text = if app.mode == AppMode::Interactive {
         // Interactive mode status with position info
         let total = app.interactive_state.elements.len();
-        let current = app.interactive_state.current_index.map(|i| i + 1).unwrap_or(0);
+        let current = app
+            .interactive_state
+            .current_index
+            .map(|i| i + 1)
+            .unwrap_or(0);
         let percentage = if total > 0 && current > 0 {
             current * 100 / total
         } else {
@@ -498,7 +519,10 @@ fn render_status_bar(frame: &mut Frame, app: &App, area: Rect) {
                 } else {
                     0
                 };
-                ("Outline", format!("{}/{} ({}%)", selected_idx + 1, total, percentage))
+                (
+                    "Outline",
+                    format!("{}/{} ({}%)", selected_idx + 1, total, percentage),
+                )
             }
             Focus::Content => {
                 // Show content scroll position
@@ -509,7 +533,10 @@ fn render_status_bar(frame: &mut Frame, app: &App, area: Rect) {
                 } else {
                     0
                 };
-                ("Content", format!("Line {} ({}%)", scroll_pos + 1, percentage))
+                (
+                    "Content",
+                    format!("Line {} ({}%)", scroll_pos + 1, percentage),
+                )
             }
         };
 
@@ -533,11 +560,7 @@ fn render_status_bar(frame: &mut Frame, app: &App, area: Rect) {
 
         format!(
             " [{}] {}{}{} • {}",
-            focus_indicator,
-            position_info,
-            bookmark_indicator,
-            history_indicator,
-            outline_status
+            focus_indicator, position_info, bookmark_indicator, history_indicator, outline_status
         )
     };
 
@@ -588,11 +611,7 @@ fn render_footer(frame: &mut Frame, app: &App, area: Rect) {
                 let element_hint = match app.interactive_state.current_element() {
                     Some(elem) => match &elem.element_type {
                         ElementType::Checkbox { .. } => {
-                            vec![
-                                ("j/k", "Navigate"),
-                                ("Space", "Toggle"),
-                                ("Esc", "Exit"),
-                            ]
+                            vec![("j/k", "Navigate"), ("Space", "Toggle"), ("Esc", "Exit")]
                         }
                         ElementType::Table { .. } => {
                             vec![
@@ -611,32 +630,16 @@ fn render_footer(frame: &mut Frame, app: &App, area: Rect) {
                             ]
                         }
                         ElementType::Details { .. } => {
-                            vec![
-                                ("j/k", "Navigate"),
-                                ("Enter", "Expand"),
-                                ("Esc", "Exit"),
-                            ]
+                            vec![("j/k", "Navigate"), ("Enter", "Expand"), ("Esc", "Exit")]
                         }
                         ElementType::CodeBlock { .. } => {
-                            vec![
-                                ("j/k", "Navigate"),
-                                ("y", "Copy"),
-                                ("Esc", "Exit"),
-                            ]
+                            vec![("j/k", "Navigate"), ("y", "Copy"), ("Esc", "Exit")]
                         }
                         ElementType::Image { .. } => {
-                            vec![
-                                ("j/k", "Navigate"),
-                                ("Enter", "Open"),
-                                ("Esc", "Exit"),
-                            ]
+                            vec![("j/k", "Navigate"), ("Enter", "Open"), ("Esc", "Exit")]
                         }
                     },
-                    None => vec![
-                        ("j/k", "Navigate"),
-                        ("Enter", "Action"),
-                        ("Esc", "Exit"),
-                    ],
+                    None => vec![("j/k", "Navigate"), ("Enter", "Action"), ("Esc", "Exit")],
                 };
                 element_hint
             }
@@ -659,17 +662,10 @@ fn render_footer(frame: &mut Frame, app: &App, area: Rect) {
             ]
         }
         AppMode::CellEdit => {
-            vec![
-                ("Enter", "Save"),
-                ("Esc", "Cancel"),
-            ]
+            vec![("Enter", "Save"), ("Esc", "Cancel")]
         }
         AppMode::CommandPalette => {
-            vec![
-                ("j/k", "Navigate"),
-                ("Enter", "Select"),
-                ("Esc", "Cancel"),
-            ]
+            vec![("j/k", "Navigate"), ("Enter", "Select"), ("Esc", "Cancel")]
         }
         _ => {
             // Normal mode - show based on focus
@@ -890,7 +886,25 @@ fn render_markdown_enhanced(
                         }
                     });
 
-                    let is_any_selected = is_item_selected || selected_link_inline_idx.is_some();
+                    // Determine which line should have the pointer based on selected link's line_offset
+                    let selected_line_offset: Option<usize> =
+                        selected_link_inline_idx.and_then(|inline_idx| {
+                            item.inline.get(inline_idx).and_then(|elem| {
+                                if let InlineElement::Link { line_offset, .. } = elem {
+                                    // Use line_offset if provided, otherwise default to 0
+                                    Some(line_offset.unwrap_or(0))
+                                } else {
+                                    None
+                                }
+                            })
+                        });
+
+                    // For checkboxes, always select line 0; for links, use their line_offset
+                    let pointer_line = if is_item_selected {
+                        Some(0)
+                    } else {
+                        selected_line_offset
+                    };
 
                     // Check if content has nested items (contains newlines with indentation)
                     let has_nested = item.content.contains('\n');
@@ -899,12 +913,15 @@ fn render_markdown_enhanced(
                         // Render multi-line item with nested items
                         let content_lines = item.content.lines();
                         for (line_idx, line) in content_lines.enumerate() {
+                            // Check if this specific line should have the pointer
+                            let show_pointer = pointer_line == Some(line_idx);
+
                             if line_idx == 0 {
                                 // First line: use regular list marker
                                 let mut spans = vec![];
 
-                                // Add selection indicator for checkboxes or links
-                                if is_any_selected {
+                                // Pointer replaces leading spaces, not prepended
+                                if show_pointer {
                                     spans.push(Span::styled(
                                         "→ ",
                                         Style::default()
@@ -912,15 +929,17 @@ fn render_markdown_enhanced(
                                             .bg(theme.selection_indicator_bg)
                                             .add_modifier(Modifier::BOLD),
                                     ));
+                                } else {
+                                    spans.push(Span::raw("  "));
                                 }
 
                                 let prefix = if let Some(checked) = item.checked {
                                     let checkbox = if checked { "☑" } else { "☐" };
-                                    format!("  {} ", checkbox)
+                                    format!("{} ", checkbox)
                                 } else if *ordered {
-                                    format!("  {}. ", idx + 1)
+                                    format!("{}. ", idx + 1)
                                 } else {
-                                    "  • ".to_string()
+                                    "• ".to_string()
                                 };
                                 let formatted = format_inline_markdown(line, theme);
                                 spans.push(Span::styled(
@@ -938,7 +957,26 @@ fn render_markdown_enhanced(
                                     let (is_task, checked, text_after_marker) =
                                         detect_checkbox_in_text(trimmed);
 
-                                    let indent = " ".repeat(indent_count + 2); // Base indent + 2
+                                    let mut spans = vec![];
+
+                                    // Calculate indent: reserve 2 chars for pointer at appropriate depth
+                                    // Base indent (2) + nested indent, with pointer replacing last 2 chars
+                                    let total_indent = indent_count + 2;
+                                    if show_pointer {
+                                        // Indent up to pointer position, then pointer
+                                        let pre_pointer_indent =
+                                            " ".repeat(total_indent.saturating_sub(2));
+                                        spans.push(Span::raw(pre_pointer_indent));
+                                        spans.push(Span::styled(
+                                            "→ ",
+                                            Style::default()
+                                                .fg(theme.selection_indicator_fg)
+                                                .bg(theme.selection_indicator_bg)
+                                                .add_modifier(Modifier::BOLD),
+                                        ));
+                                    } else {
+                                        spans.push(Span::raw(" ".repeat(total_indent)));
+                                    }
 
                                     let marker = if is_task {
                                         // Task list item with checkbox
@@ -950,13 +988,10 @@ fn render_markdown_enhanced(
 
                                     let formatted =
                                         format_inline_markdown(text_after_marker, theme);
-                                    let mut spans = vec![
-                                        Span::raw(indent),
-                                        Span::styled(
-                                            marker,
-                                            Style::default().fg(theme.list_bullet),
-                                        ),
-                                    ];
+                                    spans.push(Span::styled(
+                                        marker,
+                                        Style::default().fg(theme.list_bullet),
+                                    ));
                                     spans.extend(formatted);
                                     lines.push(Line::from(spans));
                                 } else {
@@ -975,8 +1010,8 @@ fn render_markdown_enhanced(
 
                         let mut spans = vec![];
 
-                        // Add selection indicator for checkboxes or links
-                        if is_any_selected {
+                        // Pointer replaces leading spaces, not prepended
+                        if pointer_line.is_some() {
                             spans.push(Span::styled(
                                 "→ ",
                                 Style::default()
@@ -984,15 +1019,17 @@ fn render_markdown_enhanced(
                                     .bg(theme.selection_indicator_bg)
                                     .add_modifier(Modifier::BOLD),
                             ));
+                        } else {
+                            spans.push(Span::raw("  "));
                         }
 
                         let prefix = if let Some(checked) = item.checked {
                             let checkbox = if checked { "☑" } else { "☐" };
-                            format!("  {} ", checkbox)
+                            format!("{} ", checkbox)
                         } else if *ordered {
-                            format!("  {}. ", idx + 1)
+                            format!("{}. ", idx + 1)
                         } else {
-                            "  • ".to_string()
+                            "• ".to_string()
                         };
 
                         spans.push(Span::styled(prefix, Style::default().fg(theme.list_bullet)));
@@ -1198,12 +1235,9 @@ fn render_markdown_enhanced(
                             + nested_idx * crate::tui::interactive::DETAILS_NESTED_MULTIPLIER;
 
                         // Check various offsets for different block types
-                        let table_id =
-                            nested_sub_idx + crate::tui::interactive::TABLE_OFFSET;
-                        let code_id =
-                            nested_sub_idx + crate::tui::interactive::CODE_BLOCK_OFFSET;
-                        let image_id =
-                            nested_sub_idx + crate::tui::interactive::IMAGE_OFFSET;
+                        let table_id = nested_sub_idx + crate::tui::interactive::TABLE_OFFSET;
+                        let code_id = nested_sub_idx + crate::tui::interactive::CODE_BLOCK_OFFSET;
+                        let image_id = nested_sub_idx + crate::tui::interactive::IMAGE_OFFSET;
 
                         let is_nested_selected = selected_element_id
                             .map(|sel_id| {
@@ -1243,8 +1277,7 @@ fn render_markdown_enhanced(
                                     .map(|state| state.is_in_table_mode())
                                     .unwrap_or(false);
                                 let cell = if in_mode {
-                                    interactive_state
-                                        .and_then(|state| state.get_table_position())
+                                    interactive_state.and_then(|state| state.get_table_position())
                                 } else {
                                     None
                                 };
@@ -1522,7 +1555,8 @@ fn render_block_to_lines(
             ..
         } => {
             // Render details with collapsed indicator
-            let mut summary_spans = vec![Span::styled("▶ ", Style::default().fg(theme.list_bullet))];
+            let mut summary_spans =
+                vec![Span::styled("▶ ", Style::default().fg(theme.list_bullet))];
 
             // Parse and render inline HTML in summary (e.g., <strong>Navigation</strong>)
             let summary_elements = parse_inline_html(summary);
@@ -1565,7 +1599,8 @@ fn render_block_to_lines(
                     format_inline_markdown(&item.content, theme)
                 };
 
-                let mut line_spans = vec![Span::styled(marker, Style::default().fg(theme.list_bullet))];
+                let mut line_spans =
+                    vec![Span::styled(marker, Style::default().fg(theme.list_bullet))];
                 line_spans.extend(item_spans);
                 lines.push(Line::from(line_spans));
 
@@ -1721,8 +1756,46 @@ fn format_inline_markdown<'a>(text: &str, theme: &Theme) -> Vec<Span<'a>> {
     let mut i = 0;
 
     while i < chars.len() {
+        // Check for markdown link [text](url)
+        if chars[i] == '[' {
+            // Look for the closing ] and opening (
+            let mut j = i + 1;
+            let mut link_text = String::new();
+            while j < chars.len() && chars[j] != ']' {
+                link_text.push(chars[j]);
+                j += 1;
+            }
+            // Check if followed by (url)
+            if j + 1 < chars.len() && chars[j] == ']' && chars[j + 1] == '(' {
+                let mut k = j + 2;
+                let mut url = String::new();
+                while k < chars.len() && chars[k] != ')' {
+                    url.push(chars[k]);
+                    k += 1;
+                }
+                if k < chars.len() && chars[k] == ')' {
+                    // Valid link found
+                    if !current.is_empty() {
+                        spans.push(Span::raw(current.clone()));
+                        current.clear();
+                    }
+                    // Render link text with link styling
+                    spans.push(Span::styled(
+                        link_text,
+                        Style::default()
+                            .fg(theme.link_fg)
+                            .add_modifier(Modifier::UNDERLINED),
+                    ));
+                    i = k + 1; // Move past the closing )
+                    continue;
+                }
+            }
+            // Not a valid link, treat [ as regular character
+            current.push(chars[i]);
+            i += 1;
+        }
         // Check for inline code `code`
-        if chars[i] == '`' {
+        else if chars[i] == '`' {
             if !current.is_empty() {
                 spans.push(Span::raw(current.clone()));
                 current.clear();
